@make(ais)
@aiInfo(topic=<No separator is required before or after an apostrophe>,
number=[AI-00893/02],
classcode=[ra],
statuscode=[CE],
mainref=[02.02@\(02)],
date=[92-12-09])
@aiHeading()
@begin(history)
@begin(toplines)
@mainref()
!class ramification 91-02-11
!status ARG-approved 91-03-01 (6-0-0) (pending editorial review)
@end(toplines)
!status work-item 91-02-11
!status received 83-11-17
@topic{!topic No separator is required before or after an apostrophe}
@end(history)

@subheading[!summary 91-02-11]

No separator is required before or after an apostrophe.  For legal programs,
it is always possible for an implementation to determine whether the
apostrophe is serving as a lexical element or as part of a character literal.

@subheading[!question 91-02-11]

2.2(2) says:
@begin(quotation)
In some cases an explicit @univ[separator] is required to separate
adjacent lexical elements (namely, when without separation,
interpretation as a single lexical element is possible).
@end(quotation)
Does this mean the following statement is illegal?
@begin(example)
VAR := CHARACTER'('=');         -- illegal? (no)
@end(example)
Must this qualification be written with a separator before or after the
parenthesis, since @t{'('} must otherwise be interpreted as a single lexical
element?

@subheading[!response 91-05-16]

No syntactically legal program contains the lexical sequence:
@begin(quotation)
@t{CHARACTER '(' = ' ) }
@end(quotation)
Since interpretation of '(' as a single lexical element is therefore not
possible, 2.2(2) implies that no separator is required before or after the
initial apostrophe.

Similarly, no separation is required between the elements
@begin(example)
@key[if] '(' = ')' @key[then]
@end(example)
since no syntactically legal program contains the lexical sequence
@begin(example)
@key[if] '
@end(example)
In general, it is always safe to treat an apostrophe that follows a reserved
word as part of a character literal; an apostrophe that follows an
identifier that is not a reserved word can be safely treated as a delimiter.
This interpretation has been enforced by ACVC tests that have been in the
ACVC suite since 1983.

It might well be argued that the intent of 2.2(2) was to ensure that a
lexical analyzer could simply attempt to build the longest possible lexical
element based on the lexical rules given in Chapter 2 of the Standard.  Given
such an intent, if an analyzer encounters an apostrophe that is not the
closing apostrophe of a character literal, it need only look one additional
character ahead to see whether the apostrophe is the first character of a
character literal.  But since it @dq"is possible" to unambiguously interpret '('
as a character literal in the context
@begin(example)
@key[if]'('=')'@key[then]
@end(example)
and as a sequence of two delimiters followed by the initial part of a
character literal in the context
@begin(example)
CHARACTER'('A')
@end(example)
the interpretation enforced by the ACVC tests is consistent with 2.2(2).
There is certainly no point in providing a different interpretation of this
paragraph at this time.

@cbon()@begin(appendix)
@subheading[!appendix 92-12-09]
@begin(sectionGroup)
@mybar()

!section 02.02   (02)  John Goodenough 92-12-09
!version 1983
!topic Reasoning in AI-00893/01 is wrong
@end(sectionGroup)

The AI argues:

        No syntactically legal program contains the lexical sequence:

                CHARACTER '(' = ' )

        Since interpretation of '(' as a single lexical element is therefore
        not possible, 2.2(2) implies that no separator is required before or
        after the initial apostrophe.

This argument is quite incorrect.  Consider the sequence of characters:

        ifA then B; end if;

Surely we don't say this represents the lexical sequence:

        if A then B ; end if ;

since no legal program contains the lexical sequence:

        ifA then B ; end if ;

If we applied the reasoning of the AI, we would have to say interpretation
of @t[ifA] as a single lexical element is "therefore not possible", and no
one would agree with this position!

Since we don't want to change the accepted interpretation of the language, we
must simply assert the current interpretation as a binding interpretation.

@end(appendix)@cboff()
